@@ -10,6 +10,7 @@ class DjangoWatchTowerHandler(watchtower_logging.watchtower_logging.WatchTowerHa
         protocol = getattr(settings, 'WT_PROTOCOL', 'https')
         dev = getattr(settings, 'WT_DEV', False)
         timeout = getattr(settings, 'WT_TIMEOUT', 1.0)
+        retry_count = getattr(settings, 'WT_NUM_RETRY', 1)
 
         super().__init__(
             beam_id=settings.WT_BEAM_ID,
@@ -18,4 +19,5 @@ class DjangoWatchTowerHandler(watchtower_logging.watchtower_logging.WatchTowerHa
             host=settings.WT_HOST,
             flush_interval=-1,
             dev=dev,
-            timeout=timeout)
\ No newline at end of file
+            timeout=timeout,
+            retry_count=retry_count)
\ No newline at end of file
