@@ -10,6 +10,7 @@ import string
 import datetime
 import pytz
 import traceback
+import sys
 
 DONE_LEVEL_NUM = logging.INFO + 4
 START_LEVEL_NUM = logging.INFO + 2
@@ -36,10 +37,18 @@ class logLevels(object):
 
 def logaction(self, msg, lvl_num, args, data=None, **kws):
     if self.isEnabledFor(lvl_num):
+
+        if hasattr(self, '_default_data') and isinstance(self._default_data, dict):
+            if data is None:
+                data = self._default_data
+            else:
+                data = {**self._default_data, **data}
+
         if not data is None:
             if lvl_num >= logLevels.ERROR:
                 if not 'traceback' in data:
-                    data['traceback'] = traceback.format_exc()
+                    if not sys.exc_info()[2] is None:
+                        data['traceback'] = traceback.format_exc()
 
             if 'extra' in kws:
                 if 'data' in kws['extra']:
@@ -53,7 +62,10 @@ def logaction(self, msg, lvl_num, args, data=None, **kws):
             extra = kws.pop('extra', {})
 
             if lvl_num >= logLevels.ERROR:
-                data = {'traceback': traceback.format_exc()}
+                if not sys.exc_info()[2] is None:
+                    data = {'traceback': traceback.format_exc()}
+                else:
+                    data = {}
                 if 'data' in extra:
                     raise loggingException('Duplicate `data` key, please merge the data you are passing with the entry in `extra`.')
                 extra['data'] = data
@@ -92,6 +104,14 @@ def setExecutionId(self, execution_id=None):
     else:
         self._execution_id = execution_id
 
+def setDefaultData(self, data, overwrite=False):
+    if not isinstance(data, dict):
+        raise loggingException('Default data needs to be a dictionary')
+    if not overwrite and hasattr(self, '_default_data') and isinstance(self._default_data, dict):
+        self._default_data = {**self._default_data, **data}
+    else:
+        self._default_data = data
+
 class CustomJsonFormatter(jsonlogger.JsonFormatter):
 
     converter = datetime.datetime.utcfromtimestamp
@@ -113,7 +133,7 @@ class CustomJsonFormatter(jsonlogger.JsonFormatter):
 
 
 
-def getLogger(beam_id, name=None, execution_id=None, token=None, host=None, protocol=None, dev=False,
+def getLogger(beam_id, name=None, execution_id=None, token=None, host=None, protocol=None, dev=False, default_data=None,
               level=logLevels.START, debug=False, path=None, console=False, send=True, use_threading=None, catch_all=True):
 
     # create logger
@@ -129,6 +149,10 @@ def getLogger(beam_id, name=None, execution_id=None, token=None, host=None, prot
     logger.critical = types.MethodType(critical, logger)
     logger.setExecutionId = types.MethodType(setExecutionId, logger)
     logger.setLevel(level)
+    logger.setDefaultData = types.MethodType(setDefaultData, logger)
+
+    if default_data:
+        logger.setDefaultData(data=default_data)
 
     if send:
         if use_threading is None:
